pub struct ReqwestClient { /* private fields */ }Expand description
A client for executing requests as defined by http_request_derive::HttpRequest implementations.
Implementations
Sourceimpl ReqwestClient
impl ReqwestClient
Sourcepub fn new(base_url: Url) -> Self
pub fn new(base_url: Url) -> Self
Create a new ReqwestClient from a base Url.
Sourcepub fn logger(&self) -> Option<HttpLogger>
pub fn logger(&self) -> Option<HttpLogger>
Get the logger for dumping information about the HTTP communication if it is set.
Sourcepub fn set_logger(&mut self, logger: HttpLogger)
pub fn set_logger(&mut self, logger: HttpLogger)
Set a logger for dumping information about the HTTP communication.
Sourcepub fn with_logger(self, logger: HttpLogger) -> Self
pub fn with_logger(self, logger: HttpLogger) -> Self
Return the client with a new logger for dumping the HTTP communication.
Sourcepub fn set_base_url(&mut self, base_url: Url)
pub fn set_base_url(&mut self, base_url: Url)
Sets the base URL to the given URL.
Sourcepub fn with_base_url(self, base_url: Url) -> Self
pub fn with_base_url(self, base_url: Url) -> Self
Return the client with a new base URL.